@@ -270,6 +270,16 @@ class Experimento:
         self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4 = \
             m_dist.calcula_distancias_a_objetos(self.posiciones_x, self.posiciones_y, self.lista_objetos_relevantes)
 
+        print("Distancias calculadas.")
+
+        lista_dist_objetos = [self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4]
+
+        self.distancia_minima_objetos_2_3_4, self.distancia_minima_todos_objetos, self.distancia_total_recorrida = \
+            m_dist.resultados_distancias(self.posiciones_x, self.posiciones_y, lista_dist_objetos)
+
+        print("Distancia total calculada")
+
+    def agrega_histogramas_distancias_objetos(self):
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
                                            categoria="dist_objeto_1",
                                            serie=self.dist_objeto_1)
@@ -286,15 +296,6 @@ class Experimento:
                                            categoria="dist_objeto_4",
                                            serie=self.dist_objeto_4)
 
-        print("Distancias calculadas.")
-
-        lista_dist_objetos = [self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4]
-
-        self.distancia_minima_objetos_2_3_4, self.distancia_minima_todos_objetos, self.distancia_total_recorrida = \
-            m_dist.resultados_distancias(self.posiciones_x, self.posiciones_y, lista_dist_objetos)
-
-        print("Distancia total calculada")
-
     def calcula_distancia_promediada_con_objeto(self, objeto, intervalo):
         arreglo_elegido = []
         if objeto is 1:
@@ -315,21 +316,21 @@ class Experimento:
                                                              self.posiciones_y)
         self.velocidad_maxima = round(self.serie_velocidad.max(), 3)
 
-        m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
-                                           categoria="velocidad",
-                                           serie=self.serie_velocidad)
-
         self.serie_aceleracion = m_vel.calcula_serie_aceleracion(arreglo_tiempo=self.tiempo,
                                                                  serie_velocidad=self.serie_velocidad)
 
         self.aceleracion_maxima = round(self.serie_aceleracion.max(), 3)
 
+    def agrega_histogramas_vel_acel(self):
+        m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
+                                           categoria="velocidad",
+                                           serie=self.serie_velocidad)
+
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
                                            categoria="aceleracion",
                                            serie=self.serie_aceleracion)
 
     def calcula_entropias_histogramas_vel_acel(self):
-
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="histograma_velocidad",
                                        datos=self.histogramas["velocidad"])
@@ -340,6 +341,7 @@ class Experimento:
 
     def calcula_entropias_aproximadas_vel_acel(self,
                                                tamanio_vectores,
+                                               brinco_datos,
                                                umbral,
                                                sobreposicion):
 
@@ -347,6 +349,7 @@ class Experimento:
                                                   categoria="aproximada_velocidad",
                                                   datos=self.serie_velocidad.to_numpy(),
                                                   tamanio_vectorial=tamanio_vectores,
+                                                  brinco_datos=brinco_datos,
                                                   umbral=umbral,
                                                   sobreposicion=sobreposicion)
 
@@ -354,7 +357,9 @@ class Experimento:
                                                   categoria="aproximada_aceleracion",
                                                   datos=self.serie_aceleracion.to_numpy(),
                                                   tamanio_vectorial=tamanio_vectores,
-                                                  umbral=umbral)
+                                                  brinco_datos=brinco_datos,
+                                                  umbral=umbral,
+                                                  sobreposicion=sobreposicion)
 
     def calcula_velocidades_promediadas(self, cantidad_datos_promedio):
         print("-------------------------------------------------------------")
@@ -397,10 +402,7 @@ class Experimento:
                                        categoria="histograma_aceleracion_promediada_" + str(cantidad_datos_promedio),
                                        datos=self.histogramas["aceleracion_promediada_" + str(cantidad_datos_promedio)])
 
-    def calcula_regiones_cuadriculadas(self,
-                                       tamanio_vectorial,
-                                       umbral,
-                                       sobreposicion):
+    def calcula_regiones_cuadriculadas(self):
 
         self.arreglo_region_cuadriculada, self.matriz_cuadriculada = \
             m_reg_cuad.calcula_regiones_cuadriculadas(tiempos=self.tiempo,
@@ -410,13 +412,6 @@ class Experimento:
                                                       cantidad_columnas=self.cantidad_columnas,
                                                       dimension_caja=self.dimension_caja)
 
-        m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
-                                                  categoria="visitas_regiones_aprox",
-                                                  datos=self.matriz_cuadriculada.flatten(),
-                                                  tamanio_vectorial=tamanio_vectorial,
-                                                  umbral=umbral,
-                                                  sobreposicion=sobreposicion)
-
         print(self.matriz_cuadriculada)
 
     def calcula_entropias_regiones_cuadriculadas(self):
@@ -424,6 +419,21 @@ class Experimento:
                                        categoria="visitas_regiones",
                                        datos=self.matriz_cuadriculada.flatten())
 
+    def calcula_entropias_aproximadas_regiones_cuadriculadas(self,
+                                                             tamanio_vectorial,
+                                                             umbral,
+                                                             brinco_datos,
+                                                             sobreposicion):
+
+        m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
+                                                  categoria="visitas_regiones_aprox",
+                                                  datos=self.matriz_cuadriculada.flatten(),
+                                                  tamanio_vectorial=tamanio_vectorial,
+                                                  brinco_datos=brinco_datos,
+                                                  umbral=umbral,
+                                                  sobreposicion=sobreposicion)
+
+
     def calcula_matrices_de_recurrencia(self):
         self.matriz_recurrencia_region_cuadriculada = \
             m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada)
