@@ -1,5 +1,9 @@
+from motus.graficador import graficas_disponibles as m_gd
+
+
 class ConfigGrafica:
     def __init__(self):
+        self.graficas_disponibles = m_gd.GraficasDisponibles()
 
         self.limite_eje_x_min = None
         self.limite_eje_x_max = None
@@ -53,7 +57,11 @@ class ConfigGrafica:
         return self.promedio_velocidad_aceleracion_prom
 
     def regresa_config_grafica_figuras(self):
-        return self.dist_max_figuras, self.total_figuras, self.tipo_figura, self.rot_grafica_3d
+        objetos_a_utilizar = [self.tomar_objeto_1,
+                              self.tomar_objeto_2,
+                              self.tomar_objeto_3,
+                              self.tomar_objeto_4]
+        return objetos_a_utilizar, self.dist_max_figuras, self.total_figuras, self.tipo_figura, self.rot_grafica_3d
 
     def regresa_config_grafica_regresion_lineal(self):
         return self.regresion_lineal_seleccionada
